using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using TMPro;
using UnityEngine;
using UnityEngine.UI;

namespace Fluent
{
    /// <summary>
    /// This is used to wrap the uGUI or TMP text elements so that fluent dialogue can support both.
    /// Unfortunately that means you need to import TMP into your project even it you are not using it, fortunately most are.
    /// </summary>
    public class FluentText
    {
        Text uGUIText;
        TextMeshProUGUI tmpText;

        public GameObject gameObject
        {
            get
            {
                if (uGUIText != null)
                    return uGUIText.gameObject;

                if (tmpText != null)
                    return tmpText.gameObject;

                throw new FluentException("You are trying to get the GameObject of a FluentText the element it is pointing to is null");
            }
        }

        public string text
        {
            get
            {
                if (uGUIText != null)
                    return uGUIText.text;

                if (tmpText != null)
                    return tmpText.text;

                throw new FluentException("You are trying to set text from a UI element but that element is null");
            }

            set
            {
                if (uGUIText != null)
                {
                    uGUIText.text = value;
                    return;
                }

                if (tmpText != null)
                {
                    tmpText.text = value;
                    return;
                }

                throw new FluentException("You are trying to set text on a UI element but that element is null");
            }
        }

        public static implicit operator FluentText(Text text)
        {
            return new FluentText(text);
        }

        public static implicit operator FluentText(TextMeshProUGUI text)
        {
            return new FluentText(text);
        }

        public FluentText(Text text)
        {
            uGUIText = text;
        }

        public FluentText(TextMeshProUGUI text)
        {
            tmpText = text;
        }

        public static FluentText GetComponentInChildren(GameObject go)
        {
            Text text = go.GetComponentInChildren<Text>();
            if (text != null)
                return new FluentText(text);

            TextMeshProUGUI tmpText = go.GetComponentInChildren<TextMeshProUGUI>();
            if (tmpText != null)
                return new FluentText(tmpText);

            return null;
        }

        public static FluentText GetComponent(GameObject go)
        {
            Text text = go.GetComponent<Text>();
            if (text != null)
                return new FluentText(text);

            TextMeshProUGUI tmpText = go.GetComponent<TextMeshProUGUI>();
            if (tmpText != null)
                return new FluentText(tmpText);

            return null;
        }

    }
}
